"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GetStopData = void 0;
const stream_1 = require("stream");
const fs = require("fs");
const parse = require("csv-parse");
const stringify = require("csv-stringify");
const yauzl = require("yauzl");
class GetStopData {
    constructor(http) {
        this.http = http;
    }
    async update() {
        const transform = new stream_1.Transform({
            objectMode: true,
            transform: (chunk, encoding, callback) => {
                callback(null, [chunk[0], chunk[1], chunk[4], chunk[10], chunk[14], chunk[18], chunk[19], chunk[29], chunk[30]]);
            }
        });
        await this.http.getFile(GetStopData.STOPS_URL, "/tmp/Stops.zip");
        const stream = await this.getStopsCsvStream("/tmp/Stops.zip");
        return new Promise((resolve, reject) => {
            stream
                .pipe(parse()).on("error", reject)
                .pipe(transform).on("error", reject)
                .pipe(stringify()).on("error", reject)
                .pipe(fs.createWriteStream("/tmp/Stops.csv")).on("error", reject)
                .on("finish", resolve);
        });
    }
    async getStopsCsvStream(filename) {
        return new Promise((resolve, reject) => {
            yauzl.open(filename, { lazyEntries: true }, (err, zip) => {
                if (err || !zip) {
                    return reject(err);
                }
                zip.readEntry();
                zip.on("entry", entry => {
                    if (entry.fileName === "Stops.csv") {
                        zip.openReadStream(entry, (error, readStream) => {
                            if (error || !readStream) {
                                return reject(error);
                            }
                            readStream.on("end", () => zip.readEntry());
                            resolve(readStream);
                        });
                    }
                    else {
                        zip.readEntry();
                    }
                });
            });
        });
    }
}
exports.GetStopData = GetStopData;
GetStopData.STOPS_URL = "https://naptan.app.dft.gov.uk/DataRequest/Naptan.ashx?format=csv";
